@@ -6,7 +6,7 @@ knitr::opts_chunk$set(
 )
 
 # exit if user doesn't have synapser, a log in, or access to data. 
-if (genieBPC:::.is_connected_to_genie() == FALSE){
+if (genieBPC:::.is_connected_to_genie(pat = Sys.getenv("SYNAPSE_PAT")) == FALSE){
   knitr::knit_exit()
 }
 
